#ifndef DefaultOptions_h
#define DefaultOptions_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FileInfoModel.h"
#include "FileSelectionFrame.h"
#include "FtpCommandModel.h"
#include "Util.h"
#include "XmlOptions.h"

//_____________________________________________________
//! default options installer
void installDefaultOptions( void )
{

    // set options default values
    XmlOptions::get().setAutoDefault( true );
    XmlOptions::get().keep( "APPLICATIONS" );

    // customize pixmap path
    XmlOptions::get().keep( "PIXMAP_PATH" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/128x128" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/48x48" );

    XmlOptions::get().set<int>( "DB_SIZE", 30 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_HEIGHT", 500 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_WIDTH", 700 );

    XmlOptions::get().set<bool>( "SHOW_COMMAND_LIST", false );
    XmlOptions::get().set<bool>( "SHOW_LOG", false );
    XmlOptions::get().set<bool>( "SHOW_TOOLTIPS", false );
    XmlOptions::get().set<bool>( "SHOW_HIDDEN_FILES", false );

    XmlOptions::get().set<bool>( "SAVE_PASSWORDS", false );
    XmlOptions::get().set<int>( "DEFAULT_PORT", 21 );

    XmlOptions::get().set<bool>( "USE_PREFIX", true );
    XmlOptions::get().set<bool>( "USE_TRUNCATION", true );
    XmlOptions::get().set<bool>( "SHOW_NAVIGATOR", true );

    // list mask
    XmlOptions::get().set<int>( "REMOTE_VIEW_MODE", (1<<FileInfoModel::Filename) | (1<<FileInfoModel::Size) );
    XmlOptions::get().set<int>( "REMOTE_LIST_MASK", (1<<FileInfoModel::Filename) | (1<<FileInfoModel::Size) );
    XmlOptions::get().set<int>( "LOCAL_LIST_SORT_ORDER", 0 );
    XmlOptions::get().set<int>( "REMOTE_LIST_SORT_ORDER", 0 );

    // command list
    XmlOptions::get().set<int>( "FTP_COMMAND_LIST_MASK", 1<<FtpCommandModel::Name );

    // view mode
    XmlOptions::get().set<int>( "LOCAL_VIEW_MODE", FileSelectionFrame::Icons );
    XmlOptions::get().set<int>( "REMOTE_VIEW_MODE", FileSelectionFrame::Icons );

    // pixmap size
    XmlOptions::get().set<int>( "ICON_VIEW_PIXMAP_SIZE", 48 );

    // history
    XmlOptions::get().set<bool>( "SAVE_HISTORY", false );
    XmlOptions::get().set<int>( "HISTORY_SIZE", 10 );

    // database file
    XmlOptions::get().set( "HELP_FILE", Option( File( "/.qftp_help" ).addPath( Util::home() ), Option::None ) );
    XmlOptions::get().set( "RC_FILE", Option( File(".qftprc").addPath( Util::home() ), Option::None ) );
    XmlOptions::get().setAutoDefault( false );

};

#endif
