/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FtpMacro.h"

//___________________________________________________________________
unsigned int& FtpMacro::_counter( void )
{
    static unsigned int counter( 0 );
    return counter;
}

//_______________________________________
FtpMacro::NameMap& FtpMacro::_names( void )
{
    static NameMap map;
    return map;
}

//_________________________________________
QString FtpMacro::name( const Type& type )
{
    if( _names().empty() ) _initializeNames();
    return _names()[type];
}

//_________________________________________
void FtpMacro::_initializeNames( void )
{
    _names()[None] = QObject::tr( "none" );
    _names()[Connect] = QObject::tr( "connect to host" );
    _names()[CloseConnection] = QObject::tr( "close connection" );
    _names()[Add] = QObject::tr( "add file to internal list" );
    _names()[Clear] = QObject::tr( "clear internal file list" );
    _names()[Abort] = QObject::tr( "abort transfer" );
    _names()[CopyRecursive] = QObject::tr( "copy selected items" );
    _names()[CreateDirectory] = QObject::tr( "create directory" );
    _names()[Rename] = QObject::tr( "rename selected item" );
    _names()[Remove] = QObject::tr( "remove selected items" );
    _names()[Open] = QObject::tr( "open files" );
    _names()[ShowDirectory] = QObject::tr( "query directory content" );
    _names()[ListRecursive] = QObject::tr( "query directory content (recursive)" );
    _names()[SizeRecursive] = QObject::tr( "query directory size (recursive)" );
    _names()[CheckConflicts] = QObject::tr( "check file conflicts" );
    _names()[CheckFilesCopy] = QObject::tr( "check file transfer (copy)" );
    _names()[CheckFilesMoved] = QObject::tr( "check file transfer (move)" );
    _names()[CheckFilesExist] = QObject::tr( "check file existence" );
    _names()[ClearSelection] = QObject::tr( "clear display selection" );
    _names()[Select] = QObject::tr( "update display selection" );
}

//_________________________________________
FtpMacro::FtpMacro( const Type& type ):
    Counter( "FtpMacro" ),
    type_( type ),
    id_( _counter()++ )
{}
