/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "OpenFilesDialog.h"

#include "BaseIconNames.h"
#include "CustomComboBox.h"
#include "FileDialog.h"
#include "IconEngine.h"
#include "TreeView.h"
#include "XmlOptions.h"

#include <QHeaderView>
#include <QLabel>
#include <QLayout>
#include <QScrollBar>
#include <QToolButton>

//____________________________________________________________________________
OpenFilesDialog::OpenFilesDialog( QWidget* parent, const FileInfo::List& files ):
    QuestionDialog( parent ),
    model_( this )
{

    Debug::Throw( "OpenFilesDialog::OpenFilesDialog.\n" );

    // option name
    setOptionName( "OPEN_FILES_DIALOG" );

    // customize buttons
    okButton().setText( "Open" );
    okButton().setIcon( IconEngine::get( IconNames::Edit ) );

    // label
    const QString buffer = QString( tr( "Open %1 ?" ) ).arg( files.description( FileInfo::List::Designate | FileInfo::List::LowerCase ) );
    setText( buffer );

    // file list
    TreeView* treeView = new TreeView();
    treeView->setSelectionMode( QAbstractItemView::NoSelection );
    setDetails( treeView );

    model_.setShowIcons( false );
    model_.add( files );
    model_.sort( FileInfoModel::Filename, Qt::DescendingOrder );

    // setup list
    treeView->setModel( &model_ );
    treeView->toggleShowHeader( false );
    treeView->setMask( 1<<FileInfoModel::Filename );
    treeView->header()->setSortIndicator( FileInfoModel::Filename, Qt::AscendingOrder );

    // resize list to accomodate longest item
    int maxWidth( 0 );
    foreach( const FileInfo& fileInfo, files )
    { maxWidth = qMax( maxWidth, treeView->fontMetrics().width( fileInfo.file() ) ); }

    treeView->verticalScrollBar()->adjustSize();
    treeView->setMinimumSize( QSize(
        maxWidth + treeView->verticalScrollBar()->width() + 10,
        treeView->fontMetrics().height() + 10 ) );

    showDetails();

    // combobox
    QHBoxLayout* hLayout = new QHBoxLayout();
    mainLayout().addLayout( hLayout );
    QLabel* label = new QLabel( tr( "Open with:" ), this );
    hLayout->addWidget( label );
    hLayout->addWidget( actionComboBox_ = new CustomComboBox( this ) );
    actionComboBox_->setEditable( true );
    actionComboBox_->setAutoCompletion( true );
    connect( actionComboBox_, SIGNAL(editTextChanged(QString)), SLOT(_updateButtons()) );
    label->setBuddy( actionComboBox_ );

    QToolButton* button;
    hLayout->addWidget( button = new QToolButton( this ) );
    button->setIcon( IconEngine::get( IconNames::Open ) );
    button->setAutoRaise( true );
    connect( button, SIGNAL(clicked()), SLOT(_browse()) );
    _updateButtons();

}

//______________________________________________________________________
void OpenFilesDialog::_browse( void )
{
    Debug::Throw( "OpenFilesDialog::_browse.\n" );

    // create file dialog
    QString file( FileDialog( this ).getFile() );
    if( !file.isNull() ) actionComboBox().setEditText( file );
    return;
}


//____________________________________________________________________
void OpenFilesDialog::_updateButtons( void )
{
    Debug::Throw( "OpenFilesDialog::_updateButtons.\n" );
    okButton().setEnabled( !actionComboBox().currentText().isEmpty() );
}
